// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: ActionMenu.java
// Classes: ActionMenu
// Original Author: Jason Robbins
// $Id: ActionMenu.java,v 1.2 1996/08/31 17:46:18 jrobbins Exp $

package uci.graphedit;

import java.lang.*;
import java.util.*;
import java.awt.*;



/** A combination of a java.awt.Menu with a collection of
 * uci.graphedit.Action. When a menu item is chosen, the corresponding
 * Action is exectuted. <p>
 * Needs-more-work: Currently this class is not used. It should be
 * used in class EditorMenus.
 * @see EditorMenus
 */

public class ActionMenu {
  
  /** the java.awt.Menu */
  private Menu _menu;
  
  /** keyed by the labels of menu items, with Actions as values */
  private Hashtable _actions = new Hashtable();

  /** Construct a new ActionMenu with the given label */
  public ActionMenu(String label) { _menu = new Menu(label); }

  /** Add a new item and associated action to the menu. Call this
   * function repeatedly to build up a menu */
  public void add(String itemLabel, Action act) {
    _menu.add(new MenuItem(itemLabel));
    if (act != null) _actions.put(itemLabel, act);
  }

  /** return the java.awt.Menu so that you can add it to a menu bar, or
   * another menu, or add items that do not have actions */
  public Menu menu() { return _menu; }

  /** Handle an event by finding an action associated with a menu
   * choice and executing it. Your main event handler should send this
   * message to all ActionMenu instances. */
  public boolean handleMenuEvent(Event e) {
    if (!(e.target instanceof MenuItem)) return false;
    String menuLabel = ((MenuItem)e.target).getLabel();
    Object act = _actions.get(menuLabel);
    if (act instanceof Action) {
      ((Action)act).doIt(e);
      return true;
    }
    return false;
  }

} /* end class ActionMenu */
