// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: FigList.java
// Classes: FigList
// Original Author: ics125b spring 1996
// $Id: FigList.java,v 1.5 1996/09/14 18:29:57 jrobbins Exp $

package uci.graphedit;

import java.util.*;
import java.awt.*;
import java.lang.Math;
import java.io.*;

/** This class implements a basic composite figure that holds a list
 * of Figs. */

public class FigList {

  /** The Fig's contained in this FigList */
  private Vector list;

  /** construct a new FigList that holds no Fig's. */
  public FigList() {
    super();
    list = new Vector();
  }

  /** Reply an Enumeration of the Fig's contained in this FigList */
  public Enumeration elements() { return list.elements(); }

  /** Add a Fig to the list. */
  public void addFig(Fig p) { list.addElement(p); }


  /** Retrieve the top-most Fig containing the given point, of null. <p>
   *
   * Needs-More-Work: just do a linear search.  Later, optimize this
   * routine using Quad Trees (or other) techniques */

  public final Fig pick(Point pnt) { return pick(pnt.x, pnt.y); }

  public Fig pick(int x, int y) {
    Enumeration fs = list.elements();
    Fig ret_fig = null;
    while (fs.hasMoreElements()) {
      Fig cur_fig = (Fig) fs.nextElement();
      if (cur_fig.inside(x, y)) ret_fig = cur_fig;
    }
    return ret_fig;
  }

  /** Translate all the Fig in the list by the given offset. */
  public void translate(int dx,int dy) {
    Enumeration fs = list.elements();
    while (fs.hasMoreElements()) {
      Fig cur_fig = (Fig) fs.nextElement();
      cur_fig.translate(dx, dy);
    }
  }

  /** Delete a Fig from the list */
  public void deleteFig(Fig p) { list.removeElement(p); }

  /** Delete all Fig's from the list. */
  public void removeAll() { list.removeAllElements(); }



  /** Draw all the Fig's in this list. */
  public void draw(Graphics g) {
    Enumeration fs = list.elements();
    while (fs.hasMoreElements()) {
      Fig cur_fig = (Fig) fs.nextElement();
      cur_fig.draw(g);
    }
  }

  /** Reply a list of Fig's that have a NetPort as their owner.
   * Needs-More-Work: should this be in Perspective? */
  public Vector getPortFigs() {
    Vector ret_vect = new Vector();
    Fig cur_fig;
    Enumeration fs = list.elements();
    while (fs.hasMoreElements()) {
      cur_fig = (Fig) fs.nextElement();
      if ((cur_fig.owner() != null) && (cur_fig.owner() instanceof NetPort))
	ret_vect.addElement(cur_fig);
    }
    return ret_vect;
  }

  /** Reply the list of Fig's */
  public Vector getFigList() { return list; }

  /** Accumulate a bounding box for all the Fig's in the list */
  Rectangle getBoundingBox() {
    Rectangle bbox;

    Enumeration fs = list.elements();
    if (fs.hasMoreElements()) bbox = ((Fig)fs.nextElement()).getBoundingBox();
    else return new Rectangle(0, 0, 0, 0);
    
    while (fs.hasMoreElements()) {
      Fig cur_fig = (Fig) fs.nextElement();
      bbox.add(cur_fig.getBoundingBox());
    }
    return bbox;
  }

} /* end class FigList */








