// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: Globals.java
// Classes: Globals
// Original Author: Jason Robbins
// $Id: Globals.java,v 1.2 1996/09/14 19:44:31 jrobbins Exp $

package uci.graphedit;

import java.lang.*;


/** This class stores global info that is needed by all Editors. For
 * example, it aids in communication between the various Palette's
 * and Editor's by holding the next global Mode.  */

public class Globals {

  //  public Globals() {
    /* constructor body */
  //}

  /** The user's preferences for various editor features */
  private static Prefs _prefs = new Prefs();

  /** reply the user's preferences */
  public static Prefs prefs() { return _prefs; }

  /** True if the next global Mode should remain as the next global
   * mode even after it has been given to one editor. */
  private static boolean _sticky = false;

  /** Set whether the next global mode should remain as the next
   * global mode even after it has been given to one editor. */
  public static void setSticky(boolean b) { _sticky = b; }

  /** The next global mode. This is given to an editor on mouse entry */
  private static Mode _mode;

  /** What mode should Editor's go into if the Palette is not
   * requesting a specific mode? */
  private static Mode defaultMode() { return new ModeSelect(); }

  /** Set the next global mode */
  public static void mode(Mode m) { _mode = m; }

  /** Set the next global mode, and set it's stickiness */
  public static void mode(Mode m, boolean s) {
    _mode = m;
    _sticky = s;
  }

  /** Reply the next global mode. */
  public static Mode mode() {
    if (_mode == null) _mode = defaultMode();
    return _mode;
  }

  /** Determine the next global mode. This is called when a mode
   * finishes whatever it was meant to accomplish. For now, a sticky
   * mode stays the next global mode, all other modes are "popped" off
   * a single element stack and the defaultMode becomes the next
   * global mode. In the future it may be useful to have a true stack
   * of pending modes, I don't know.
   *
   * @see Mode#done */
  public static Mode nextMode() {
    if (!_sticky) _mode = defaultMode();
    return _mode;
  }

  /** The Editor that most recently contained the mouse */
  private static Editor _curEditor;

  /** Setthe current Editor */
  public static void curEditor(Editor ce) { _curEditor = ce; }
  
  /** Reply the Editor that most recently contained the mouse */
  public static Editor curEditor() { return _curEditor; }

} /* end class Globals */
