// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: ShapePalette.java
// Classes: ShapePalette
// Original Author: ics125b spring 1996
// $Id: PaletteShape.java,v 1.2 1996/09/17 19:04:44 jrobbins Exp $

package uci.graphedit;


import java.awt.*;
import java.util.*;

/** A Palette that defines buttons to create lines, rectangles,
 * circles, and text. Also a select button is provided to switch back
 * to ModeSelect. 
 *
 * @see ModeSelect
 * @see ModeCreateFigLine
 * @see ModeCreateFigRect
 * @see ModeCreateFigCircle
 * @see ModeCreateFigText
 */

public class PaletteShape extends Palette {
  /** the buttons on the palette */
  public Button circle_button;
  public Button rect_button;
  public Button line_button;
  public Button text_button;
  public Button select_button;

  /** The Editor Mode to enter when the user clicks on one of the
   * above buttons. Clicking on a button sets the next global Mode in
   * Globals. The next time an Editor gets a mouse entered event it
   * will set its mode to the stored next global Mode. */
  final String ModeCreateFigTextCLASS = "uci.graphedit.ModeCreateFigText";
  final String ModeCreateFigLineCLASS = "uci.graphedit.ModeCreateFigLine";
  final String ModeCreateFigRectangleCLASS = "uci.graphedit.ModeCreateFigRectangle";
  final String ModeSelectCLASS = "uci.graphedit.ModeSelect";
  final String ModeCreateFigCircleCLASS = "uci.graphedit.ModeCreateFigCircle";


  /** Construct a new Paletteshape and set the name of the Frame to
   * "Shape" (if applicable). */

  public PaletteShape() { super(2, 1, "Shapes"); }

  /** Defined the buttons in this palette. Each of these buttons is
   * associated with an ActionSetMode, and that Action sets the next
   * global Mode to somethign appropriate. All the buttons can stick
   * except 'select'. If the user unclicks the sticky checkbox, the
   * 'select' button is automatically pressed. */
  public Vector defineButtons() {
    Vector v = new Vector();
    Action setSelect = new ActionSetMode(ModeSelectCLASS);
    Action addCircle = new ActionSetMode(ModeCreateFigCircleCLASS);
    Action addRect = new ActionSetMode(ModeCreateFigRectangleCLASS);
    Action addLine = new ActionSetMode(ModeCreateFigLineCLASS);
    Action addText = new ActionSetMode(ModeCreateFigTextCLASS);

    ActionButton selectButton = new ActionButton("Select", setSelect);
    ActionButton circleButton = new ActionButton("Circle", addCircle);
    ActionButton rectButton = new ActionButton("Rect", addRect);
    ActionButton lineButton = new ActionButton("Line", addLine);
    ActionButton textButton = new ActionButton("Text", addText);


    circleButton.canStick(true);
    rectButton.canStick(true);
    lineButton.canStick(true);
    textButton.canStick(true);

    v.addElement(selectButton);
    v.addElement(circleButton);
    v.addElement(rectButton);
    v.addElement(lineButton);
    v.addElement(textButton);

    onUnstick(selectButton);

    return v;
  }


} /* end class PaletteShape */






