// Copyright (c) 1995, 1996 Regents of the University of California.
// All rights reserved.
//
// This software was developed by the Arcadia project
// at the University of California, Irvine.
//
// Redistribution and use in source and binary forms are permitted
// provided that the above copyright notice and this paragraph are
// duplicated in all such forms and that any documentation,
// advertising materials, and other materials related to such
// distribution and use acknowledge that the software was developed
// by the University of California, Irvine.  The name of the
// University may not be used to endorse or promote products derived
// from this software without specific prior written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
// IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
// WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.

// File: PrefsEditor.java
// Classes: PrefsEditor
// Original Author: Jason Robbins
// $Id: PrefsEditor.java,v 1.3 1996/09/17 23:18:40 jrobbins Exp $

package uci.graphedit;

import java.lang.*;
import java.util.*;
import java.awt.*;


/** A dialog box to let the user edit various preferences that effect
 * the applicatioon. Needs-More-Work: right now the only preference
 * that can be edited is whether the user wants to use flicker-free
 * redraw. I should add prefs for handle colors, grid snap(?), and
 * some behaviors...  */

public class PrefsEditor extends Frame {
  /** A check box for using flicker-free graphics */
  private Checkbox _tryOffScreenCB;
  /** The close button */
  private Button _close;

  /** Construct a new PrefsEditor and get ready to open it. This can
   * be invoked via ActionOpenWindow.
   *
   * @see ActionOpenWindow */    
  public PrefsEditor() { 
    setTitle("Prefs");
    _tryOffScreenCB = new Checkbox("Flicker-free redraw");
    Panel p = new Panel();
    p.setLayout(new GridLayout(2,1));
    _tryOffScreenCB.setState(Globals.prefs().tryOffScreen());
    p.add(_tryOffScreenCB);
    add("Center", p);
    _close = new Button("Close");
    Panel bottomPanel = new Panel();
    bottomPanel.add("Center",_close);
    add("South", bottomPanel);
    pack();
  }

  /** Close the PrefEditor window */
  public void close() { hide(); dispose(); }

  /** If the user wants to close the window, do it. */
  public boolean handleEvent(Event e) {
    switch(e.id) {
    case Event.WINDOW_DESTROY:
      close();
      return true;
    }
    return super.handleEvent(e);
  }

  /** If the use pushes one of the buttons, update
   * Globals.prefs(). Needs-More-Work: It would be nice to have a more
   * compact way to code this. I expect that every preference that can
   * be edited will affect Globals.prefs() in a similiar way. */
  public boolean action(Event e, Object what) {
    if (e.target == _tryOffScreenCB) {
      Globals.prefs().tryOffScreen(!Globals.prefs().tryOffScreen());
      _tryOffScreenCB.setState(Globals.prefs().tryOffScreen());
      return true;
    }
    else if (e.target == _close) {
      close();
      return true;
    }
    return false;
  }
  
} /* end class PrefsEditor */
